<?php // skeerel - Skeerel core functions



// disable direct file access
if ( ! defined( 'ABSPATH' ) ) {
	
	exit;
	
}

/**
 * Display Skeerel button on the product page
 *
 */
function skeerel_display_button_product_page() {

	require_once plugin_dir_path( __DIR__ ) . 'vendor/autoload.php';
	
	$skeerel_options = get_option( 'woocommerce_skeerel_settings');

	if ( $skeerel_options["display_skeerel_on_product_page"] != "yes" )
		return;

	// check if skeerel is enabled
	if( $skeerel_options['enabled'] == "no" )
		return;

	// check if skeerel payments are only available for administrators
	if( $skeerel_options['admin_only'] == "yes" && !current_user_can( 'manage_woocommerce' ) )
		return;

	global $product;

	if( $product->is_type('external') )	// skeerel does not support variable/grouped products yet (product page only)
		return;

	$product_id = $product->get_id().':1:0';

	if( is_null (\Skeerel\Util\Session::get(\Skeerel\Skeerel::DEFAULT_COOKIE_NAME)) )
		\Skeerel\Skeerel::generateSessionStateParameter();
	
	?>

	<div id="skeerel-pay-button" style="display: inline-block !important; padding: 10px 8px !important; border-radius: 4px !important; background: rgb(239, 75, 75) !important; cursor: pointer !important;"><i style="display: inline-block !important; width: 20px !important; height: 20px !important; vertical-align: middle !important; background-image: url(&quot;https://api.skeerel.com/assets/v2/images/skeerel_white.png&quot;) !important; background-size: 20px 20px !important; background-repeat: no-repeat !important; margin-right: 4px !important;"></i>
	<a style="font-family: Roboto, Arial, sans-serif !important; font-size: 14px !important; color: rgb(255, 255, 255) !important; vertical-align: middle !important; border: 0px !important; background: none !important; -webkit-appearance: none !important; cursor: pointer !important; outline: none !important; text-decoration: none !important; text-transform: none !important; font-weight: normal !important; padding: 0px !important; margin: 0px !important; text-shadow: none !important; box-shadow: none !important; height: auto !important; border-radius: 0px !important; transition: none 0s ease 0s !important; display: inline !important; line-height: 1 !important;" id="skeerel_payment_btn"><?php echo $skeerel_options['button_text_on_product_page'] ?></a></div>

	<?php 
	
		// load external script
		wp_enqueue_script( 'skeerel-api-js', "https://api.skeerel.com/assets/v2/javascript/api.min.js" , array(), true, false );

	$bool = array( '0' => "false", '1' => "true" );
	$js_addition = "

    ( function ($) {
	var skeerelCheckout;
	var previous_custom = '';

      $('#skeerel-pay-button').on('click', function() {

		var custom = '';
		var price = 0;
		var product_price;

		// variable product
           	if( $('.product:first').hasClass('product-type-variable') && !$('.product:first').hasClass('product-type-simple') ) {
                	var product_qty = $('.qty').val() || 1;
                	var product_id = $('input[name=\"product_id\"]').val();
                	var variation_id = $('input[name=\"variation_id\"]').val() || 0;

					try {
						if( $('.woocommerce-variation-price .amount:visible').length == 1 )
							product_price = $('.woocommerce-variation-price .amount:visible').html().match(/\d+/);
						else
							product_price = $('ins .amount:visible').html().match(/\d+/);
					} catch( e ) {
						product_price = 0;
					}

					price += product_price * product_qty;
					custom = product_id+':'+product_qty+':'+variation_id;
		} else if ( $('.product').hasClass('woocommerce-grouped-product-list-item') ) {
					$('form.cart tr').each(function() {
                		var product_qty = $(this).find('.qty').val() || 1;
                		var product_id = $(this).attr('id').match(/\d+/);
                		var variation_id = 0;
						
						if( $(this).find('.amount').length == 1 )
							product_price = $(this).find('.amount').html().match(/\d+/);
						else
							product_price = $(this).find('ins .amount').html().match(/\d+/);

						price += product_price * product_qty;			
						custom += product_id+':'+product_qty+':'+variation_id+',';
        		});

				custom = custom.slice(0,-1);
		} else {
			var product_qty = $('.qty').val() || 1;
			var product_id = $('.product').attr('id').match(/\d+/);
			var variation_id = 0;
			var product_price = ".$product->get_price()."
			price += product_price * product_qty;

			custom = product_id+':'+product_qty+':'+variation_id;
		}

	if( price <= 0 ) {
		alert( \"".esc_html__("Veuillez sélectionner certaines options du produit avant de l’ajouter à votre panier.", 'skeerel')."\");
		return;
	}

	if( previous_custom != custom ) {

	if( typeof skeerelCheckout !== 'undefined' ) {
		skeerelCheckout.cancel();
	}
                

        skeerelCheckout = new SkeerelCheckout(
                \"".$skeerel_options['skeerel_id']."\", // Website id
                \"".\Skeerel\Util\Session::get(\Skeerel\Skeerel::DEFAULT_COOKIE_NAME)."\", // state parameter
                \"".wc_get_checkout_url()."?product_checkout\", // redirect url
                ". $bool [ $product->needs_shipping() ] .", // needs shipping address?
                '". esc_url_raw( rest_url() )."' + 'skeerel/v1/get-delivery-methods?product_id=' + custom + '&zip_code=__ZIP_CODE__&country=__COUNTRY__', // delivery methods url
                price*100, // amount to pay
                'eur', // currency
                null, // profile id
                custom, // custom data
                ". $bool [( $skeerel_options['use_test_mode'] == "yes" )]." // is test mode?
        );

        	// Create and show the iframe
        	skeerelCheckout.start();
			previous_custom = custom;
	} else {
		$('#skeerel-api-iframe-div').css('display', 'block');
	}
    });
    } ) ( jQuery );"; 

	wp_add_inline_script( 'skeerel-api-js', $js_addition );

}

add_action( 'woocommerce_after_add_to_cart_form', 'skeerel_display_button_product_page' );

/**
* Process payment on product page
*/
function skeerel_process_product_payment() {

    require_once plugin_dir_path( __DIR__ ) . 'vendor/autoload.php';

    global $wp;
    global $woocommerce;

    if( home_url( $wp->request ).'/' == wc_get_checkout_url() 
	&& isset($_GET['product_checkout']) && isset($_GET['token']) && !empty($_GET['token']) && isset($_GET['state']) && !empty($_GET['state'])) {
       
	// Verify that the state parameter is the same to avoid XSRF attacks
       if ( \Skeerel\Skeerel::verifyAndRemoveSessionStateParameter($_GET['state']) ) {

	  $skeerel_options = get_option( 'woocommerce_skeerel_settings');

      $skeerel = new \Skeerel\Skeerel( $skeerel_options['skeerel_id'], $skeerel_options['skeerel_secret_key'] );

      $data = $skeerel->getData($_GET['token']);
	  $custom = $data->getCustom();
	  $custom = explode(',', $custom);
	  
	  $ship_to = $data->getDelivery()->getShippingAddress();

	  // save cart
	  $current_cart = $woocommerce->cart->get_cart_contents();

	  $woocommerce->cart->empty_cart(); 
	  
	  foreach( $custom as $product ) {
		  $product = explode(':', $product);
		  $woocommerce->cart->add_to_cart( $product[0], $product[1], $product[2] ); // $product_id , $quantity, $variation_id
	  }
	  
	  $woocommerce->customer->set_shipping_location( $ship_to->getCountry()->getAlpha2(), '', $ship_to->getZipCode());
	  $woocommerce->session->set('chosen_shipping_methods', array( $data->getDelivery()->getMethodId() ) );
	  
	  set_transient( 'skeerel_wc_shipping_method', $data->getDelivery()->getMethodId() );  
	  add_filter('woocommerce_shipping_chosen_method', function($method) { return get_transient('skeerel_wc_shipping_method'); }, 10);
	 
	  $woocommerce->cart->calculate_shipping();
  	  $woocommerce->cart->calculate_totals();

	  $total = $woocommerce->cart->get_totals()['total'];

	  // check if the total are equal. 
	  if ( (int)($total*100) == $data->getPayment()->getAmount() && 
			(
				( $skeerel_options['use_test_mode'] == "no" && $data->getPayment()->isLive() ) ||	// check if payment status matches 'use test mode'
				( $skeerel_options['use_test_mode'] == "yes" && !$data->getPayment()->isLive() )	  
			)  
	  ) {
		  
		$checkout = $woocommerce->checkout();

		$order_id = $checkout->create_order( array('payment_method' => 'skeerel') );
		$order = wc_get_order( $order_id );

		$user = $data->getUser();
		$billing = $data->getPayment()->getBillingAddress();
		
		$order->set_address( array( 
        			'first_name' =>  $user->getFirstName(),
        			'last_name'  =>  $user->getLastName(),
				'company'    =>  ($billing->isCompany()) ? $billing->getCompanyName() : '',
        			'email'      =>  $user->getMail(),
      				'phone'      =>  $ship_to->getPhone(),
        			'address_1'  =>  $ship_to->getAddress(),
        			'address_2'  =>  $ship_to->getAddressLine2().' '.$ship_to->getAddressLine3(),
        			'city'       =>  $ship_to->getCity(),
        			'postcode'   =>  $ship_to->getZipCode(),
				'country'    =>  $ship_to->getCountry()->getAlpha2()
		), 'shipping' );


                $order->set_address( array(
                                'first_name' =>  $user->getFirstName(),
                                'last_name'  =>  $user->getLastName(),
				'company'    =>  ($billing->isCompany()) ? $billing->getCompanyName() : '',
                                'email'      =>  $user->getMail(),
                                'phone'      =>  $billing->getPhone(),
                                'address_1'  =>  $billing->getAddress(),
                                'address_2'  =>  $billing->getAddressLine2().' '.$ship_to->getAddressLine3(),
                                'city'       =>  $billing->getCity(),
                                'postcode'   =>  $billing->getZipCode(),
                                'country'    =>  $billing->getCountry()->getAlpha2()
                ), 'billing' );

		update_post_meta($order_id, '_customer_user', get_current_user_id());
		$order->add_meta_data( '_custom_skeerel_payment_id', $data->getPayment()->getId() );

		$order->calculate_totals();
		$order->payment_complete(); 
		
		// if test mode is active, append [TEST] to every note
		$test_append = ( $skeerel_options['use_test_mode'] == 'yes' ) ? '[TEST] ' : '';

		// if company, add note 
		if ( $billing->isCompany() && !empty( $billing->getVatNumber() ) ) {
			$order->add_order_note( __("L'entreprise a pour numéro de TVA : ", 'skeerel').$billing->getVatNumber() );
		}

		// check if the payment has been captured or not
		if ( $data->getPayment()->isCaptured() ) {
			$order->add_order_note( $test_append.__("Commande validée. L'argent a été transféré sur votre compte Skeerel.", 'skeerel') );
		} else {
			$order->set_status( 'on-hold', $test_append.__("Ce paiement semble suspect. Si vous jugez qu'il s'agit d'un paiement légitime, cliquez sur Action > Capturer le paiement. ", 'skeerel') );
		}

		$order->save();

		set_transient( 'skeerel_wc_cart_saved', $current_cart, 60 * 5);
		set_transient( 'skeerel_wc_order_id' , $order->get_id(), 60 * 5);		

		// redirect to order-received page
        wp_redirect( $order->get_checkout_order_received_url() );	
		exit;

	  } else {
		wp_die( esc_html__('Une erreur est survenue. Merci de bien vouloir réessayer.', 'skeerel') );
	  }
       }
    }
}

add_action('wp', 'skeerel_process_product_payment');

/**
* Process payment at checkout
*/
function skeerel_process_checkout_payment() {

    require_once plugin_dir_path( __DIR__ ) . 'vendor/autoload.php';

    global $wp;
    global $woocommerce;

    if( home_url( $wp->request ).'/' == wc_get_checkout_url() 
	&& isset($_GET['checkout']) && isset($_GET['token']) && !empty($_GET['token']) && isset($_GET['state']) && !empty($_GET['state'])) {
       
	// Verify that the state parameter is the same to avoid XSRF attacks
       if ( \Skeerel\Skeerel::verifyAndRemoveSessionStateParameter($_GET['state']) ) {

	  $skeerel_options = get_option( 'woocommerce_skeerel_settings');

          $skeerel = new \Skeerel\Skeerel( $skeerel_options['skeerel_id'], $skeerel_options['skeerel_secret_key'] );

          $data = $skeerel->getData($_GET['token']);
	  $custom = $data->getCustom();

          // empty cart
          $woocommerce->cart->empty_cart();
	  $custom_parts = explode('|', $custom);

	  // promo codes detected ?
	  if( count( $custom_parts ) == 2 ) {
		$custom_products = $custom_parts[1];

		// apply promo codes
		$promo_codes = explode(',', $custom_parts[0]);
		foreach( $promo_codes as $key => $value ) {
			$woocommerce->cart->apply_coupon($value);

		}

	  } else {
		$custom_products = $custom_parts[0];
	  }

	  $custom_products = explode(',', $custom_products);

	  // load the cart 
	  foreach( $custom_products as $custom ) {
		$custom = explode(':', $custom);
	 	$woocommerce->cart->add_to_cart( $custom[0], $custom[1], $custom[2] ); // $product_id , $quantity, $variation_id
	  }

	  if ($data->getDelivery() != null) {
          $woocommerce->customer->set_shipping_location( $data->getDelivery()->getShippingAddress()->getCountry()->getAlpha2(), '', $data->getDelivery()->getShippingAddress()->getZipCode());
          $woocommerce->session->set('chosen_shipping_methods', array( $data->getDelivery()->getMethodId() ) );

          set_transient( 'skeerel_wc_shipping_method', $data->getDelivery()->getMethodId() );
          add_filter('woocommerce_shipping_chosen_method', function($method) { return get_transient('skeerel_wc_shipping_method'); }, 10);
      }

	  $woocommerce->cart->calculate_shipping();
  	  $woocommerce->cart->calculate_totals();

	  $total = $woocommerce->cart->get_totals()['total'];

	  // check if the total are equal
	  if ( (int)($total*100) == $data->getPayment()->getAmount() && 
			(
				( $skeerel_options['use_test_mode'] == "no" && $data->getPayment()->isLive() ) ||	// check if payment status matches 'use test mode'
				( $skeerel_options['use_test_mode'] == "yes" && !$data->getPayment()->isLive() )	  
			)  
	  ) {
		$checkout = $woocommerce->checkout();

		$order_id = $checkout->create_order( array('payment_method' => 'skeerel') );
		$order = wc_get_order( $order_id );

		$user = $data->getUser();
		$billing = $data->getPayment()->getBillingAddress();

		if ($data->getDelivery() != null) {
            $order->set_address( array(
                'first_name' =>  $user->getFirstName(),
                'last_name'  =>  $user->getLastName(),
                'email'      =>  $user->getMail(),
                'phone'      =>  $data->getDelivery()->getShippingAddress()->getPhone(),
                'address_1'  =>  $data->getDelivery()->getShippingAddress()->getAddress(),
                'address_2'  =>  $data->getDelivery()->getShippingAddress()->getAddressLine2().' '.$data->getDelivery()->getShippingAddress()->getAddressLine3(),
                'city'       =>  $data->getDelivery()->getShippingAddress()->getCity(),
                'postcode'   =>  $data->getDelivery()->getShippingAddress()->getZipCode(),
                'country'    =>  $data->getDelivery()->getShippingAddress()->getCountry()->getAlpha2()
            ), 'shipping' );
        }

        $order->set_address( array(
                        'first_name' =>  $user->getFirstName(),
                        'last_name'  =>  $user->getLastName(),
                        'email'      =>  $user->getMail(),
                        'phone'      =>  $billing->getPhone(),
                        'address_1'  =>  $billing->getAddress(),
                        'address_2'  =>  $billing->getAddressLine2().' '.$billing->getAddressLine3(),
                        'city'       =>  $billing->getCity(),
                        'postcode'   =>  $billing->getZipCode(),
                        'country'    =>  $billing->getCountry()->getAlpha2()
        ), 'billing' );

		update_post_meta($order_id, '_customer_user', get_current_user_id());
		$order->add_meta_data( '_custom_skeerel_payment_id', $data->getPayment()->getId() );

		$order->calculate_totals();
		$order->payment_complete(); 

		// if test mode is active, append [TEST] to every note
		$test_append = ( $skeerel_options['use_test_mode'] == 'yes' ) ? '[TEST] ' : '';
		
		// check if the payment has been captured or not
		if ( $data->getPayment()->isCaptured() ) {
			$order->add_order_note( $test_append.__("Commande validée. L'argent a été transféré sur votre compte Skeerel.", 'skeerel') );
		} else {
			$order->set_status( 'on-hold', $test_append.__("Ce paiement semble suspect. Si vous jugez qu'il s'agit d'un paiement légitime, cliquez sur Action > Capturer le paiement. ", 'skeerel') );
		}

		$order->save();

		// redirect to order-received page
        wp_redirect( $order->get_checkout_order_received_url() );	
		exit;

	  } else {
		wp_die( esc_html__('Une erreur est survenue. Merci de bien vouloir réessayer.', 'skeerel') );
	  }
       }
    }
}

add_action('wp', 'skeerel_process_checkout_payment');

// woocommerce automatically empties the cart when redirecting to the order-received page
// the function restores the woocommerce cart to its previous state; transients expire after 5 minutes
function skeerel_restore_wc_cart() {
	global $woocommerce;
	global $wp;

	if( get_transient ( 'skeerel_wc_cart_saved' ) && isset( $wp->query_vars['order-received'] ) &&
		$wp->query_vars['order-received'] == get_transient( 'skeerel_wc_order_id' ) ) { // only apply to current order

			$current_cart = get_transient ( 'skeerel_wc_cart_saved' );

			foreach( $current_cart as $key => $values ) {
					$woocommerce->cart->add_to_cart( $values['product_id'], $values['quantity'], $values['variation_id'], $values['variation']);
			}

	}
}

add_action('woocommerce_thankyou_skeerel', 'skeerel_restore_wc_cart');

// If the payment is on-hold, add capture payment option
function skeerel_add_order_capture_payment_to_command_list( $actions ) {
    global $theorder;
    
    if ( $theorder->get_payment_method() == 'skeerel' && $theorder->get_status() == 'on-hold' ) {
            $actions['wc_skeerel_capture_payment'] = __( 'Capturer le paiement', 'skeerel' ); // add capture payment option
    } 

    return $actions;
}
add_action( 'woocommerce_order_actions', 'skeerel_add_order_capture_payment_to_command_list' );

// If the payment is on-hold, add reject payment option
function skeerel_add_order_reject_payment_to_command_list( $actions ) {
    global $theorder;
    
    if ( $theorder->get_payment_method() == 'skeerel' && $theorder->get_status() == 'on-hold' ) {
            $actions['wc_skeerel_reject_payment'] = __( 'Rejeter le paiement', 'skeerel' ); // add capture payment option
    } 

    return $actions;
}
add_action( 'woocommerce_order_actions', 'skeerel_add_order_reject_payment_to_command_list' );


/**
 * Capture user payment
 *
 * @param \WC_Order $order
 */
function skeerel_on_hold_capture_payment( $order ) {
   $skeerel_options = get_option( 'woocommerce_skeerel_settings');
   $skeerel_payment_id = $order->get_meta( '_custom_skeerel_payment_id', true );

   try {
   	$skeerel = new \Skeerel\Skeerel( $skeerel_options['skeerel_id'], $skeerel_options['skeerel_secret_key'] );
   	$skeerel->capturePayment( $skeerel_payment_id );

   	$order->set_status( 'processing', __("Le paiement a été capturé. L'argent est disponible sur votre compte Skeerel. ", 'skeerel') );
    } catch ( Exception $e ) {
	$order->add_order_note( __("La paiement n'a pas pu être capturé. Si le problème persiste, contactez Skeerel.", 'skeerel') );
    }

}
add_action( 'woocommerce_order_action_wc_skeerel_capture_payment', 'skeerel_on_hold_capture_payment' );

/**
 * Reject user payment
 *
 * @param \WC_Order $order
 */
function skeerel_on_hold_reject_payment( $order ) {
   $skeerel_options = get_option( 'woocommerce_skeerel_settings');
   $skeerel_payment_id = $order->get_meta( '_custom_skeerel_payment_id', true );

   try {
   	$skeerel = new \Skeerel\Skeerel( $skeerel_options['skeerel_id'], $skeerel_options['skeerel_secret_key'] );
   	$skeerel->rejectPayment( $skeerel_payment_id );

   	$order->set_status( 'processing', __("Le paiement a été rejeté. Les fonds ne seront pas transférés vers votre compte Skeerel.", 'skeerel') );
    } catch ( Exception $e ) {
	$order->add_order_note( __("La paiement n'a pas pu être rejeté. Si le problème persiste, contactez Skeerel.", 'skeerel') );
    }

}
add_action( 'woocommerce_order_action_wc_skeerel_reject_payment', 'skeerel_on_hold_reject_payment' );

function skeerel_display_button_at_checkout() {

	require_once plugin_dir_path( __DIR__ ) . 'vendor/autoload.php';
	$skeerel_options = get_option( 'woocommerce_skeerel_settings');

	if ( $skeerel_options["display_skeerel_at_checkout"] != "yes" || $skeerel_options["enabled"] == "no" )
		return;

	// check if skeerel payments are only available for administrators
	if( $skeerel_options['admin_only'] == "yes" && !current_user_can( 'manage_woocommerce' ) )
		return;

	// select skeerel by default

	global $woocommerce;
	$total = ( $woocommerce->cart->get_subtotal() - $woocommerce->cart->get_discount_total() )*100;
	$product_ids = "";

	foreach( $woocommerce->cart->get_cart() as $cart_item ){
        	$product_ids = $product_ids.$cart_item['data']->get_id().":".$cart_item['quantity'].":".$cart_item['variation_id'].",";
	}

	if( $product_ids != "" )
		$product_ids = substr($product_ids, 0, -1);

	$custom_field = $product_ids;

	// check if a coupon has been applied to this order
	$coupons = $woocommerce->cart->get_coupons();

	if( !empty( $coupons ) ) {
	$list_coupons = "";

	foreach ( $coupons as $key => $value ) {
		$list_coupons = $list_coupons.$value->get_code().",";
	}

	if( $list_coupons != "" )
		$list_coupons = substr( $list_coupons, 0, -1 );

		$custom_field = $list_coupons."|".$custom_field;
	}

	$previous_price = get_transient( 'skeerel_checkout_price' );

	if( is_null (\Skeerel\Util\Session::get(\Skeerel\Skeerel::DEFAULT_COOKIE_NAME)) )
		\Skeerel\Skeerel::generateSessionStateParameter();

    wp_enqueue_script( 'skeerel-api-js', "https://api.skeerel.com/assets/v2/javascript/api.min.js" , array(), true, false );

    $bool = array( '0' => "false", '1' => "true" );
    $js_addition = "
        var skeerelCheckout = new SkeerelCheckout(
                \"".$skeerel_options['skeerel_id']."\", // Website id
                \"".\Skeerel\Util\Session::get(\Skeerel\Skeerel::DEFAULT_COOKIE_NAME)."\", // state parameter
                \"".wc_get_checkout_url()."?checkout\", // redirect url
                ". $bool[ $woocommerce->cart->needs_shipping_address() ] .", // needs shipping address?
                '". esc_url_raw( rest_url() )."' + 'skeerel/v1/get-delivery-methods?product_id={$product_ids}&zip_code=__ZIP_CODE__&country=__COUNTRY__', // delivery methods url
				{$total}, // amount to pay
                'eur', // currency
                null, // profile id
                \"{$custom_field}\", // custom data
                ". $bool[( $skeerel_options['use_test_mode'] == "yes" )] ." // is test mode?
        );";
    wp_add_inline_script( 'skeerel-api-js', $js_addition );
	?>

    <?php
    if (array_key_exists("display_skeerel_encart_at_checkout", $skeerel_options) && $skeerel_options["display_skeerel_encart_at_checkout"] == "yes") {
    ?>
   <div id="skeerel_pay" style="display:none">
   <h3> <?php echo esc_html__("Payez en 1 clic avec Skeerel", "skeerel") ?> </h3>

   <h5> <?php echo esc_html__("Payez en 1 clic avec Skeerel par carte bancaire, Google Pay ou Apple Pay. Cliquez directement sur le bouton de paiement sans remplir le formulaire.", "skeerel") ?>
&nbsp;<a href="https://skeerel.com/telecharger/" style="color: #1f96cf;" onclick="javascript:window.open('https://skeerel.com/telecharger/','Skeerel','toolbar=no, location=no,directories=no, status=no, menubar=no, scrollbars=yes, resizable=yes, width=1200, height=700'); return false;"><?php echo esc_attr__( "En savoir plus", 'skeerel' ); ?> </a></h5>

    <div id="order_review" style="float:left; width:100%">
    	<?php include_once plugin_dir_path( dirname( __DIR__ ) ).'woocommerce/templates/checkout/review-order.php' ?>
    </div>

	<div id="skeerel-pay-button" style="display: inline-block !important; padding: 10px 8px !important; border-radius: 4px !important; background: rgb(239, 75, 75) !important; cursor: pointer !important;"><i style="display: inline-block !important; width: 20px !important; height: 20px !important; vertical-align: middle !important; background-image: url(&quot;https://api.skeerel.com/assets/v2/images/skeerel_white.png&quot;) !important; background-size: 20px 20px !important; background-repeat: no-repeat !important; margin-right: 4px !important;"></i>
	<a style="font-family: Roboto, Arial, sans-serif !important; font-size: 14px !important; color: rgb(255, 255, 255) !important; vertical-align: middle !important; border: 0px !important; background: none !important; -webkit-appearance: none !important; cursor: pointer !important; outline: none !important; text-decoration: none !important; text-transform: none !important; font-weight: normal !important; padding: 0px !important; margin: 0px !important; text-shadow: none !important; box-shadow: none !important; height: auto !important; border-radius: 0px !important; transition: none 0s ease 0s !important; display: inline !important; line-height: 1 !important;" id="skeerel_payment_btn"><?php echo $skeerel_options['button_text_at_checkout'] ?></a></div>

	<?php
	$js_addition = "
      document.getElementById('skeerel-pay-button').onclick = function() {
        // Create and show the iframe
        skeerelCheckout.start();
    };";

	wp_add_inline_script( 'skeerel-api-js', $js_addition );
	?>

	<br><br>
	<h4><?php echo esc_html__("ou", "skeerel") ?></h4>
	</div>

	<?php
    }
}

add_action( 'woocommerce_checkout_before_customer_details', 'skeerel_display_button_at_checkout' );

function skeerel_custom_jquery_add_to_checkout(){
	$skeerel_options = get_option( 'woocommerce_skeerel_settings');

	if( !is_checkout() || $skeerel_options['enabled'] == 'no' || $skeerel_options["display_skeerel_at_checkout"] != "yes" )
		return;

        global $woocommerce;
        $total = ( $woocommerce->cart->get_subtotal() - $woocommerce->cart->get_discount_total() );

    if (array_key_exists("display_skeerel_encart_at_checkout", $skeerel_options) && $skeerel_options["display_skeerel_encart_at_checkout"] == "yes") {
        $add_to_js = "
			(function($){
				var init=false;

				$( document.body ).on('payment_method_selected', function(){
					if( $(\"input[name='payment_method']:checked\").val() == 'skeerel' && init ) {
						$('#skeerel_pay').slideDown();
						$('html, body').stop().animate({
								scrollTop: $('#skeerel_pay').offset().top - 400
						}, 500, 'linear');
						$('.shipping').hide();
						$('.order-total td').html( '".wc_price( $total )."' + \"<span style='font-weight:400'>". esc_html__(" + frais de ports (calculés dans l'application Skeerel)", 'skeerel'). "</span>\");
						$('#customer_details input,textarea').prop('disabled', true);
						$('select').prop('disabled', true);
					}
				   else {
						 $('.shipping').show(); // unmask shipping options
						 $('#customer_details input,textarea').prop('disabled', false);
						 $('select').prop('disabled', false);			
						 $( document.body ).trigger('update_checkout'); // update total
						 $('#skeerel_pay').find('.shipping').hide();
						 $('#skeerel_pay').find('.order-total td').html( '".wc_price( $total )."' + \"<span style='font-weight:400'>".esc_html__(" + frais de ports (calculés dans l'application Skeerel)", 'skeerel')." </span>\");
				   }


					$('#place_order').on('click', function(e) { 
						if( $(\"input[name='payment_method']:checked\").val() == 'skeerel' ) {	
							e.preventDefault();
							// Create and show the iframe
                            skeerelCheckout.start();
						}
					});

				});

			$( document.body ).on('init_checkout', function(){
					init=true;
					setTimeout(function() {
							$('#skeerel_pay').find('.woocommerce-checkout-review-order-table').removeClass('woocommerce-checkout-review-order-table');
							$('#skeerel_pay').slideDown();
								$('html, body').stop().animate({
										scrollTop: $('#skeerel_pay').offset().top - 400
								}, 500, 'linear');

							if( $(\"input[name='payment_method']:checked\").val() == 'skeerel') {
								$('.shipping').hide();
								$('.order-total td').html( '".wc_price( $total )."' + \"<span style='font-weight:400'>". esc_html__(" + frais de ports (calculés dans l'application Skeerel)", 'skeerel'). "</span>\");
								$('#customer_details input,textarea').prop('disabled', true);
								$('select').prop('disabled', true);
							}
						   else {
								 $('.shipping').show(); // unmask shipping options
								 $('#customer_details input,textarea').prop('disabled', false);
								 $('select').prop('disabled', false);			
								 $( document.body ).trigger('update_checkout'); // update total
								 $('#skeerel_pay').find('.shipping').hide();
								 $('#skeerel_pay').find('.order-total td').html( '".wc_price( $total )."' + \"<span style='font-weight:400'>".esc_html__(" + frais de ports (calculés dans l'application Skeerel)", 'skeerel')." </span>\");
						   }

						  $('#place_order').on('click', function(e) {
									if( $(\"input[name='payment_method']:checked\").val() == 'skeerel' ) {
											e.preventDefault();
											// Create and show the iframe
                                            skeerelCheckout.start();
									}
						  });
				}, 1500);
		});

		 $( document.body ).on( 'update_checkout', function(event, custom){
                       if( typeof custom !== 'undefined' && custom.update_shipping_method === false ) // add/delete coupon
				setTimeout(function() {  
					location.reload(true); // refresh the page
				}, 500);

		});
		})(jQuery);";

        if( wp_script_is( 'skeerel-api-js', 'enqueued') )
            wp_add_inline_script( 'skeerel-api-js', $add_to_js );
    } else {


        $add_to_js = "
			(function($){
				var init=false;

				$( document.body ).on('payment_method_selected', function(){
					if( $(\"input[name='payment_method']:checked\").val() == 'skeerel' && init ) {
						$('.shipping').hide();
						$('.order-total td').html( '".wc_price( $total )."' + \"<span style='font-weight:400'>". esc_html__(" + frais de ports (calculés dans l'application Skeerel)", 'skeerel'). "</span>\");
						$('#customer_details input,textarea').prop('disabled', true);
						$('select').prop('disabled', true);
					}
				   else {
						 $('.shipping').show(); // unmask shipping options
						 $('#customer_details input,textarea').prop('disabled', false);
						 $('select').prop('disabled', false);			
						 $( document.body ).trigger('update_checkout'); // update total
				   }

					$('#place_order').on('click', function(e) { 
						if( $(\"input[name='payment_method']:checked\").val() == 'skeerel' ) {	
							e.preventDefault();
							// Create and show the iframe
                            skeerelCheckout.start();
						}
					});

				});

			$( document.body ).on('init_checkout', function(){
					init=true;
					setTimeout(function() {
							if( $(\"input[name='payment_method']:checked\").val() == 'skeerel') {
								$('.shipping').hide();
								$('.order-total td').html( '".wc_price( $total )."' + \"<span style='font-weight:400'>". esc_html__(" + frais de ports (calculés dans l'application Skeerel)", 'skeerel'). "</span>\");
								$('#customer_details input,textarea').prop('disabled', true);
								$('select').prop('disabled', true);
							}
						   else {
								 $('.shipping').show(); // unmask shipping options
								 $('#customer_details input,textarea').prop('disabled', false);
								 $('select').prop('disabled', false);			
								 $( document.body ).trigger('update_checkout'); // update total
						   }

						  $('#place_order').on('click', function(e) {
									if( $(\"input[name='payment_method']:checked\").val() == 'skeerel' ) {
											e.preventDefault();
											// Create and show the iframe
                                            skeerelCheckout.start();
									}
						  });
				}, 1500);
		});

		 $( document.body ).on( 'update_checkout', function(event, custom){
                       if( typeof custom !== 'undefined' && custom.update_shipping_method === false ) // add/delete coupon
				setTimeout(function() {  
					location.reload(true); // refresh the page
				}, 500);

		});
		})(jQuery);";

        if( wp_script_is( 'skeerel-api-js', 'enqueued') )
            wp_add_inline_script( 'skeerel-api-js', $add_to_js );


    }


				
}

add_action('wp_footer','skeerel_custom_jquery_add_to_checkout');


